import enum
from dataclasses import dataclass
from typing import Union


class CallbackQueryMethod(str, enum.Enum):
    CREATE = 'CREATE'
    SELECT = 'SELECT_ONE'
    SELECT_MULTIPLE = 'SELECT_MULTIPLE'
    EDIT = 'EDIT'
    DELETE = 'DELETE'


@dataclass
class CallbackQueryEvent:
    user_id: Union[str, int]
    method: CallbackQueryMethod


class MessageMethod(str, enum.Enum):
    pass


class MessageEvent:
    user_id: Union[str, int]
    text: str



import abc

from aiohttp import web


class BasePluginHandler(abc.ABC):
    async def handle_message_event(self, request: web.Request) -> None:
        pass

    async def handle_callback_query_event(self, request: web.Request) -> None:
        pass






import json
from dataclasses import dataclass

from bot_plugin.domain.access_type import AccessType
from bot_plugin.domain.plugin_context import PluginContext


@dataclass
class PluginRequest:
    url: str
    context: PluginContext
    access_type: AccessType = AccessType.PUBLIC

    def to_json(self):
        return json.dumps(self, default=lambda o: o.__dict__)



from dataclasses import dataclass, field
from typing import Optional, List, Self


@dataclass
class PluginContext:
    resource_id: str
    path: Optional[str] = None
    children: List[Self] = field(default_factory=list)



import aiohttp as aiohttp

from bot_plugin.consts.routes import AppRoutes
from bot_plugin.domain.plugin_request import PluginRequest


class AppClient:
    def __init__(self, app_url: str):
        self._app_url = app_url

    async def plugin(self, request: PluginRequest):
        async with aiohttp.ClientSession(self._app_url) as session:
            async with session.post(AppRoutes.PLUGIN_MODULE, json=request.to_json()) as response:
                response.raise_for_status()
